<?php
/**
 * Customizer Control: wp-moose-slider
 *
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( class_exists( 'Moose_Customize_Control' ) && ! class_exists( 'Moose_Slider_Customize_Control' ) ) {
	/**
	 * Slider control.
	 */
	class Moose_Slider_Customize_Control extends Moose_Customize_Control {
		/**
		 * Set the control type.
		 *
		 * @var string $type
		 */
		public $type = 'wp-moose-slider';

		/**
		 * The control description.
		 *
		 * @var string
		 */
		public $description = '';

		/**
		 * The control sub-description.
		 *
		 * @var string
		 */
		public $sub_description = '';

		/**
		 * Refresh the parameters passed to the JavaScript via JSON.
		 *
		 * @see WP_Customize_Control::to_json()
		 */
		public function to_json() {
			parent::to_json();

			$devices = array( 'desktop', 'tablet', 'mobile' );
			foreach ( $devices as $device ) {
				$this->json['choices'][ $device ]['min']  = ( isset( $this->choices[ $device ]['min'] ) ) ? $this->choices[ $device ]['min'] : '0';
				$this->json['choices'][ $device ]['max']  = ( isset( $this->choices[ $device ]['max'] ) ) ? $this->choices[ $device ]['max'] : '100';
				$this->json['choices'][ $device ]['step'] = ( isset( $this->choices[ $device ]['step'] ) ) ? $this->choices[ $device ]['step'] : '1';
				$this->json['choices'][ $device ]['edit'] = ( isset( $this->choices[ $device ]['edit'] ) ) ? $this->choices[ $device ]['edit'] : false;
				$this->json['choices'][ $device ]['unit'] = ( isset( $this->choices[ $device ]['unit'] ) ) ? $this->choices[ $device ]['unit'] : false;
			}

			foreach ( $this->settings as $setting_key => $setting_id ) {
				$this->json[ $setting_key ] = array(
					'link'    => $this->get_link( $setting_key ),
					'value'   => $this->value( $setting_key ),
					'default' => isset( $setting_id->default ) ? $setting_id->default : '',
				);
			}

			$this->json['desktop_label'] = esc_html__( 'Desktop', 'wp-moose' );
			$this->json['tablet_label']  = esc_html__( 'Tablet', 'wp-moose' );
			$this->json['mobile_label']  = esc_html__( 'Mobile', 'wp-moose' );
			$this->json['reset_label']   = esc_html__( 'Reset', 'wp-moose' );

			$this->json['description']     = $this->description;
			$this->json['sub_description'] = $this->sub_description;
		}

		/**
		 * An Underscore (JS) template for this control's content (but not its container).
		 *
		 * Class variables for this control class are available in the `data` JS object;
		 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
		 *
		 * @return void
		 * @see WP_Customize_Control::print_template()
		 * @since 1.0.0
		 */
		protected function content_template() {
			?>
            <div class="wp-moose-range-slider-control">
                <div class="wp-moose-range-title-area">
                    <label class="customizer-text">
                        <# if ( data.label ) { #><span class="customize-control-title">{{{ data.label }}}</span><# } #>
                    </label>

                    <div class="wp-moose-range-slider-controls">
						<span class="wp-moose-device-controls">
							<# if ( 'undefined' !== typeof ( data.desktop ) ) { #>
								<span class="wp-moose-device-desktop dashicons dashicons-desktop"
                                      data-option="desktop" title="{{ data.desktop_label }}">
								</span>
							<# } #>

							<# if ( 'undefined' !== typeof (data.tablet) ) { #>
								<span class="wp-moose-device-tablet dashicons dashicons-tablet"
                                      data-option="tablet" title="{{ data.tablet_label }}"></span>
							<# } #>

							<# if ( 'undefined' !== typeof (data.mobile) ) { #>
								<span class="wp-moose-device-mobile dashicons dashicons-smartphone"
                                      data-option="mobile" title="{{ data.mobile_label }}">
								</span>
							<# } #>
						</span>

                        <span title="{{ data.reset_label }}"
                              class="wp-moose-reset dashicons dashicons-image-rotate">
                        </span>
                    </div>
                </div>

                <label class="customizer-text">
                    <# if ( data.description ) { #><p class="description">{{{ data.description }}}</p><# } #>
                </label>

                <div class="wp-moose-range-slider-areas">
                    <# var devices = ['desktop', 'tablet', 'mobile'] #>
                    <# devices.forEach(function (device) { #>
                    <# if ( 'undefined' !== typeof ( data[device] ) ) { #>
                    <label class="range-option-area" data-option="{{{device}}}" style="display: none;">
                        <div class="wrapper <# if ( '' !== data.choices[device]['unit'] ) { #>has-unit<# } #>">
                            <div class="wp-moose-slider" data-step="{{ data.choices[device]['step'] }}"
                                 data-min="{{ data.choices[device]['min'] }}"
                                 data-max="{{ data.choices[device]['max'] }}"></div>

                            <div class="wp_moose_range_value">
                                <input
                                <# if ( data.choices[device]['edit'] ) { #>
                                style="display:inline-block;"
                                <# } else { #>style="display:none;"<# } #>
                                type="number" step="{{data.choices[device]['step'] }}"
                                class="{{device}}-range value"
                                value="{{data[device].value }}"
                                min="{{ data.choices[device]['min'] }}"
                                max="{{data.choices[device]['max'] }}"
                                {{{ data[device].link }}}
                                data-reset_value="{{data[device].default }}"
                                />
                                <span
                                <# if ( ! data.choices[device]['edit'] ) { #>
                                style="display:inline-block;"
                                <# } else { #>style="display:none;"<# } #>
                                class="value">{{ data[device].value }}
                                </span>

                                <# if ( data.choices[device]['unit'] ) { #>
                                <span class="unit">{{ data.choices[device]['unit'] }}</span>
                                <# } #>
                            </div>
                        </div>
                    </label>
                    <# } #>
                    <# }); #>
                </div>

                <# if ( data.sub_description ) { #>
                <p class="description sub-description">{{{ data.sub_description }}}</p>
                <# } #>
            </div>
			<?php
		}
	}
}