<?php

function get_wp_moose_default_colors()
{
    $colors = array(
        'primary_color'   => array(
        'label'   => esc_html__( 'Primary Color', 'wp-moose' ),
        'default' => '#fcb92b',
        'palette' => array(),
    ),
        'primary_focus'   => array(
        'label'   => esc_html__( 'Primary Focus', 'wp-moose' ),
        'default' => '#ffc852',
        'palette' => array(),
    ),
        'primary_content' => array(
        'label'   => esc_html__( 'Primary Content', 'wp-moose' ),
        'default' => '#181830',
        'palette' => array(),
    ),
    );
    return $colors;
}

if ( !function_exists( 'wp_moose_register_colors_options' ) ) {
    /**
     * Add colors section and controls.
     *
     * @param \WP_Customize_Manager $wp_customize
     */
    function wp_moose_register_colors_options( $wp_customize, $section_id )
    {
        // Register out color settings
        foreach ( get_wp_moose_default_colors() as $id => $arg ) {
            wp_moose_register_options( $wp_customize, array(
                'name'           => 'wp_moose_' . $id,
                'label'          => $arg['label'],
                'setting'        => array(
                'default'           => $arg['default'],
                'sanitize_callback' => 'sanitize_hex_color',
            ),
                'section'        => $section_id,
                'custom_control' => \WP_Customize_Color_Control::class,
            ) );
        }
        wp_moose_go_to_upsell(
            $wp_customize,
            $section_id,
            'wp_moose_colors_go_to_upsell',
            esc_html__( 'Want More Colors? See Moose Pro', 'wp-moose' )
        );
    }

}
if ( !function_exists( 'get_wp_moose_color' ) ) {
    /**
     * Get custom color value.
     *
     * @param string $color_name
     *
     * @return string
     */
    function get_wp_moose_color( $color_name )
    {
        $defaults = get_wp_moose_default_colors();
        
        if ( isset( $defaults[$color_name] ) ) {
            $color = get_theme_mod( 'wp_moose_' . $color_name, $defaults[$color_name]['default'] );
        } else {
            $color = get_theme_mod( 'wp_moose_' . $color_name );
        }
        
        return apply_filters( 'wp_moose_filter_color_' . $color_name, $color );
    }

}
if ( !function_exists( 'get_wp_moose_color_rgb_value' ) ) {
    /**
     * Get custom color in rgb value
     *
     * @param $color_name
     *
     * @return string
     */
    function get_wp_moose_color_rgb_value( $color_name )
    {
        list( $r, $g, $b ) = wp_moose_hex_to_rgb( get_wp_moose_color( $color_name ) );
        return $r . ',' . $g . ',' . $b;
    }

}