<?php

if ( ! function_exists( 'wp_moose_register_container_options' ) ) {
	/**
	 * Add container section and controls.
	 *
	 * @param \WP_Customize_Manager $wp_customize
	 */
	function wp_moose_register_container_options( $wp_customize, $section_id, $priority = 100 ) {
		$wp_customize->add_section( $section_id, array(
			'title'    => esc_html__( 'Container', 'wp-moose' ),
			'panel'    => 'wp_moose_appearance_panel',
			'priority' => $priority,
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'    => 'wp_moose_posts_container_style',
			'label'   => esc_html__( 'Archive Container Style', 'wp-moose' ),
			'type'    => 'select',
			'section' => $section_id,
			'choices' => wp_moose_get_container_style_options(),
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'    => 'wp_moose_page_container_style',
			'label'   => esc_html__( 'Page Container Style', 'wp-moose' ),
			'type'    => 'select',
			'section' => $section_id,
			'choices' => wp_moose_get_container_style_options(),
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'    => 'wp_moose_blog_container_style',
			'label'   => esc_html__( 'Single Post Container Style', 'wp-moose' ),
			'type'    => 'select',
			'section' => $section_id,
			'choices' => wp_moose_get_container_style_options(),
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'    => 'wp_moose_sidebar_container_style',
			'label'   => esc_html__( 'Sidebar Container Style', 'wp-moose' ),
			'type'    => 'select',
			'section' => $section_id,
			'choices' => wp_moose_get_container_style_options(),
		) );
	}
}

if ( ! function_exists( 'get_wp_moose_override_container_style' ) ) {
	/**
	 * Get override container style
	 *
	 * @return mixed|null
	 */
	function get_wp_moose_override_container_style() {
		global $post;

		// Check if single template.
		if ( $post && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'wp_moose_settings', true );
			if ( isset( $post_options['container_style'] ) && ! empty( $post_options['container_style'] ) ) {
				return $post_options['container_style'];
			}
		}

		return null;
	}
}

if ( ! function_exists( 'get_wp_moose_posts_container_style' ) ) {
	function get_wp_moose_posts_container_style() {
		return wp_moose_get_container_style_css(
			get_wp_moose_option( 'wp_moose_posts_container_style' )
		);
	}
}

if ( ! function_exists( 'get_wp_moose_sidebar_container_style' ) ) {
	function get_wp_moose_sidebar_container_style() {
		return wp_moose_get_container_style_css(
			get_wp_moose_option( 'wp_moose_sidebar_container_style' )
		);
	}
}

if ( ! function_exists( 'get_wp_moose_page_container_style' ) ) {
	function get_wp_moose_page_container_style() {
		$style = get_wp_moose_option( 'wp_moose_page_container_style' );
		if ( $override = get_wp_moose_override_container_style() ) {
			$style = $override;
		}

		return wp_moose_get_container_style_css( $style );
	}
}

if ( ! function_exists( 'get_wp_moose_blog_container_style' ) ) {
	function get_wp_moose_blog_container_style() {
		$style = get_wp_moose_option( 'wp_moose_blog_container_style' );
		if ( $override = get_wp_moose_override_container_style() ) {
			$style = $override;
		}

		return wp_moose_get_container_style_css( $style );
	}
}
