<?php

if ( ! function_exists( 'wp_moose_register_sidebar_options' ) ) {
	/**
	 * Add layout section and controls.
	 *
	 * @param \WP_Customize_Manager $wp_customize
	 */
	function wp_moose_register_sidebar_options( $wp_customize, $section_id, $priority = 100 ) {

		$wp_customize->add_section( $section_id, array(
			'title'    => esc_html__( 'Sidebar', 'wp-moose' ),
			'panel'    => 'wp_moose_appearance_panel',
			'priority' => $priority,
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'           => 'wp_moose_posts_sidebar_layout',
			'label'          => esc_html__( 'Archive Sidebar Layout', 'wp-moose' ),
			'choices'        => wp_moose_get_sidebar_layout_options(),
			'section'        => $section_id,
			'custom_control' => Moose_Image_Radio_Button_Customize_Control::class,
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'           => 'wp_moose_store_sidebar_layout',
			'label'          => esc_html__( 'Store Sidebar Layout', 'wp-moose' ),
			'choices'        => wp_moose_get_sidebar_layout_options(),
			'section'        => $section_id,
			'custom_control' => Moose_Image_Radio_Button_Customize_Control::class,
			'control_args'   => array(
				'active_callback' => function () {
					return WP_MOOSE_WOOCOMMERCE_ACTIVE;
				}
			)
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'           => 'wp_moose_page_sidebar_layout',
			'label'          => esc_html__( 'Page Sidebar Layout', 'wp-moose' ),
			'choices'        => wp_moose_get_sidebar_layout_options(),
			'section'        => $section_id,
			'custom_control' => Moose_Image_Radio_Button_Customize_Control::class,
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'           => 'wp_moose_blog_sidebar_layout',
			'label'          => esc_html__( 'Single Post Sidebar Layout', 'wp-moose' ),
			'choices'        => wp_moose_get_sidebar_layout_options(),
			'section'        => $section_id,
			'custom_control' => Moose_Image_Radio_Button_Customize_Control::class,
		) );
	}
}

if ( ! function_exists( 'get_wp_moose_override_sidebar_layout' ) ) {
	/**
	 * Get override post layout
	 *
	 * @return mixed|null
	 */
	function get_wp_moose_override_sidebar_layout() {
		global $post;

		// Check if single template.
		if ( $post && is_singular() ) {
			$post_options = get_post_meta( $post->ID, 'wp_moose_settings', true );
			if ( isset( $post_options['sidebar_layout'] ) && ! empty( $post_options['sidebar_layout'] ) ) {
				return $post_options['sidebar_layout'];
			}
		}

		return null;
	}
}

if ( ! function_exists( 'get_wp_moose_sidebar_layout' ) ) {
	/**
	 * Get sidebar layout
	 *
	 * @return string
	 */
	function get_wp_moose_sidebar_layout( $type = 'posts' ) {
		if ( $layout = get_wp_moose_override_sidebar_layout() ) {
			return $layout;
		}

		return get_wp_moose_option( "wp_moose_{$type}_sidebar_layout" );
	}
}
