<?php

if ( ! function_exists( 'wp_moose_register_single_post_options' ) ) {
	/**
	 * Add single post options and controls.
	 *
	 * @param \WP_Customize_Manager $wp_customize
	 * @param string $section_id
	 * @param int $priority
	 */
	function wp_moose_register_single_post_options( $wp_customize, $section_id, $priority = 100 ) {
		$wp_customize->add_section( $section_id, array(
			'title'    => esc_html__( 'Single Post Settings', 'wp-moose' ),
			'panel'    => '',
			'priority' => $priority,
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'           => 'wp_moose_single_post_structure',
			'label'          => esc_html__( 'Post Structure', 'wp-moose' ),
			'section'        => $section_id,
			'custom_control' => Moose_Sortable_Customize_Control::class,
			'choices'        => array(
				'title-metas'    => array(
					'label' => esc_html__( 'Title & Metas', 'wp-moose' )
				),
				'content'        => array(
					'label' => esc_html__( 'Content', 'wp-moose' )
				),
				'category'       => array(
					'label' => esc_html__( 'Category', 'wp-moose' )
				),
				'featured-image' => array(
					'label' => esc_html__( 'Featured Image', 'wp-moose' )
				)
			),
		) );

		wp_moose_register_options( $wp_customize, array(
			'name'           => 'wp_moose_single_post_metas',
			'label'          => esc_html__( 'Post Metas', 'wp-moose' ),
			'section'        => $section_id,
			'custom_control' => Moose_Sortable_Customize_Control::class,
			'choices'        => array(
				'comments'  => array(
					'label' => esc_html__( 'Comments', 'wp-moose' )
				),
				'byline'    => array(
					'label' => esc_html__( 'Byline', 'wp-moose' )
				),
				'posted_on' => array(
					'label' => esc_html__( 'Posted On', 'wp-moose' )
				),
				'tags'      => array(
					'label' => esc_html__( 'Tags', 'wp-moose' )
				),
				'views'     => array(
					'label'       => esc_html__( 'Views', 'wp-moose' ),
					'disabled'    => ! function_exists( 'pvc_get_post_views' ),
					'description' => function_exists( 'pvc_get_post_views' ) ? '' : esc_html__( 'Post Views Counter plugin is required', 'wp-moose' ),
				),
			),
		) );
	}
}
