<?php

if ( !function_exists( 'wp_moose_dynamic_vars' ) ) {
    function wp_moose_dynamic_vars()
    {
        $vars = array();
        /**
         * Palette
         */
        $colors = array(
            'primary-color'   => 'primary_color',
            'primary-focus'   => 'primary_focus',
            'primary-content' => 'primary_content',
        );
        foreach ( $colors as $var => $name ) {
            $vars['--wp-moose-' . $var] = get_wp_moose_color_rgb_value( $name );
        }
        return wp_moose_parse_css( array(
            ':root' => $vars,
        ) );
    }

}
/**
 * Create dynamic css for our theme.
 *
 * @return string
 */
function wp_moose_dynamic_css()
{
    $css = array();
    
    if ( wp_moose_is_hero_visible() ) {
        /**
         * Hero shape divider
         */
        $shape = get_wp_moose_option( 'wp_moose_hero_shape_divider' );
        $shape_data = wp_moose_get_shapes( $shape );
        
        if ( $shape_data ) {
            $color = get_wp_moose_option( 'wp_moose_hero_shape_color' );
            $width = get_wp_moose_option( 'wp_moose_hero_shape_width' );
            $height = get_wp_moose_option( 'wp_moose_hero_shape_height' );
            $flip = get_wp_moose_option( 'wp_moose_hero_shape_flip' ) && in_array( 'wp_moose_hero_shape_flip', $shape_data['options'] );
            $css['.wp-moose-hero-shape-divider svg'] = array(
                'width'     => 'calc(' . $width . '% + 1.3px)',
                'height'    => $height . 'px',
                'transform' => ( $flip ? 'translateX(-50%) rotateY(180deg)' : 'translateX(-50%)' ),
            );
            if ( $color !== '' ) {
                $css['.wp-moose-hero-shape-divider .wp-moose-shape-fill'] = array(
                    'fill' => $color,
                );
            }
        }
    
    }
    
    return wp_moose_parse_css( $css );
}

if ( !function_exists( 'wp_moose_add_global_vars' ) ) {
    /**
     * Global css vars
     */
    function wp_moose_add_global_vars()
    {
        wp_register_style( 'wp-moose-dynamic-vars', false );
        wp_enqueue_style( 'wp-moose-dynamic-vars' );
        wp_add_inline_style( 'wp-moose-dynamic-vars', wp_moose_dynamic_vars() );
    }

}
add_action( 'wp_enqueue_scripts', 'wp_moose_add_global_vars', 60 );
add_action( 'admin_enqueue_scripts', 'wp_moose_add_global_vars' );
if ( !function_exists( 'wp_moose_add_dynamic_css' ) ) {
    /**
     * Add dynamic css.
     */
    function wp_moose_add_dynamic_css()
    {
        wp_register_style( 'wp-moose-dynamic', false );
        wp_enqueue_style( 'wp-moose-dynamic' );
        wp_add_inline_style( 'wp-moose-dynamic', wp_moose_dynamic_css() );
    }

}
add_action( 'wp_enqueue_scripts', 'wp_moose_add_dynamic_css', 60 );